==> org-lsst-ccs-buses-definition-5.3.20-sources.jar: org/lsst/ccs/bus/data/RuntimeInfo.java <==
package org.lsst.ccs.bus.data;

import com.sun.management.OperatingSystemMXBean;
import java.io.Serializable;
import java.lang.management.ManagementFactory;
import org.lsst.ccs.bus.annotations.DataAttributes;

/**
 * A Class to capture the Health of the running process.
 * 
 * @author The LSST CCS Team
 * 
 */
public final class RuntimeInfo implements Serializable {
    
    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = -72154637904826248L;
    
    @DataAttributes( description = "Number of Threads allocated by the CCS process", units = "unitless")
    private final int nThreads;

    @DataAttributes( description = "Maximum Memory available to the JVM", units = "bytes")
    private final long maxMemory = Runtime.getRuntime().maxMemory();

    @DataAttributes( description = "Total Memory allocated by JVM", units = "bytes")
    private final long totalMemory;

    @DataAttributes( description = "Free Memory available that could be used by the JVM", units = "bytes")
    private final long freeMemory;

    @DataAttributes( description = "Recent cpu usage for the whole system. This value is a double in the [0.0,1.0] interval.", units = "unitless")
    private final double processCpuLoad;

    @DataAttributes( description = "Recent cpu usage for the JVM process. This value is a double in the [0.0,1.0] interval.", units = "unitless")
    private final double systemCpuLoad;
    private transient static final OperatingSystemMXBean osBean = ManagementFactory.getPlatformMXBean(OperatingSystemMXBean.class);
    private transient static final Runtime runtime = Runtime.getRuntime();

    @DataAttributes( description = "Number of seconds since the CCS process was started", units = "s")
    private final int uptime;

    public RuntimeInfo() {
        this(0);
    }
    
    public RuntimeInfo(int uptime) {
        this.nThreads = Thread.activeCount();
        this.freeMemory = runtime.freeMemory();
        this.totalMemory = runtime.totalMemory();        
        this.processCpuLoad = osBean.getProcessCpuLoad();
        this.systemCpuLoad = osBean.getSystemCpuLoad();
        this.uptime = uptime;
    }
    

    /**
     * Get the number of threads currently used.
     * @return The number of threads.
     */
    public int getNThreads() {
        return nThreads;
    }

    /**
     * Get the maximum memory allocated for the JVM in bytes
     * @return The maximum memory in bytes
     */
    public long getMaxMemory() {
        return maxMemory;
    }

    /**
     * Get the total memory currently used by the JVM in bytes
     * @return The total memory used in bytes
     */
    public long getTotalMemory() {
        return totalMemory;
    }

    /**
     * Get the JVM free memory in bytes
     * @return The free memory used in bytes
     */
    public long getFreeMemory() {
        return freeMemory;
    }

    /**
     * Get the process current CPU load.
     * @return The current CPU load.
     */
    public double getProcessCpuLoad() {
        return processCpuLoad;
    }

    /**
     * Get the system CPU load.
     * @return The system CPU load.
     */
    public double getSystemCpuLoad() {
        return systemCpuLoad;
    }
    
    /**
     * Get the Agent's uptime in milliseconds.
     * This is the amount of time since the Agent was created.
     * @return The subsystem uptime in milliseconds.
     */
    public int getUptime() {
        return uptime;
    }

}

==> org-lsst-ccs-buses-definition-6.1.9-sources.jar: org/lsst/ccs/bus/data/RuntimeInfo.java <==
package org.lsst.ccs.bus.data;

import com.sun.management.OperatingSystemMXBean;
import java.io.Serializable;
import java.lang.management.ManagementFactory;
import org.lsst.ccs.bus.annotations.DataAttributes;

/**
 * A Class to capture the Health of the running process.
 * 
 * @author The LSST CCS Team
 * 
 */
public final class RuntimeInfo implements Serializable {
    
    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = -72154637904826248L;
    
    @DataAttributes( description = "Number of Threads allocated by the CCS process", units = "unitless")
    private final int nThreads;

    @DataAttributes( description = "Maximum Memory available to the JVM", units = "bytes")
    private final long maxMemory = Runtime.getRuntime().maxMemory();

    @DataAttributes( description = "Total Memory allocated by JVM", units = "bytes")
    private final long totalMemory;

    @DataAttributes( description = "Free Memory available that could be used by the JVM", units = "bytes")
    private final long freeMemory;

    @DataAttributes( description = "Recent cpu usage for the whole system. This value is a double in the [0.0,1.0] interval.", units = "unitless")
    private final double processCpuLoad;

    @DataAttributes( description = "Recent cpu usage for the JVM process. This value is a double in the [0.0,1.0] interval.", units = "unitless")
    private final double systemCpuLoad;
    private transient static final OperatingSystemMXBean osBean = ManagementFactory.getPlatformMXBean(OperatingSystemMXBean.class);
    private transient static final Runtime runtime = Runtime.getRuntime();

    @DataAttributes( description = "Number of seconds since the CCS process was started", units = "s")
    private final int uptime;

    public RuntimeInfo() {
        this(0);
    }
    
    public RuntimeInfo(int uptime) {
        this.nThreads = ManagementFactory.getThreadMXBean().getThreadCount();
        this.freeMemory = runtime.freeMemory();
        this.totalMemory = runtime.totalMemory();        
        this.processCpuLoad = osBean.getProcessCpuLoad();
        this.systemCpuLoad = osBean.getSystemCpuLoad();
        this.uptime = uptime;
    }
    

    /**
     * Get the number of threads currently used.
     * @return The number of threads.
     */
    public int getNThreads() {
        return nThreads;
    }

    /**
     * Get the maximum memory allocated for the JVM in bytes
     * @return The maximum memory in bytes
     */
    public long getMaxMemory() {
        return maxMemory;
    }

    /**
     * Get the total memory currently used by the JVM in bytes
     * @return The total memory used in bytes
     */
    public long getTotalMemory() {
        return totalMemory;
    }

    /**
     * Get the JVM free memory in bytes
     * @return The free memory used in bytes
     */
    public long getFreeMemory() {
        return freeMemory;
    }

    /**
     * Get the process current CPU load.
     * @return The current CPU load.
     */
    public double getProcessCpuLoad() {
        return processCpuLoad;
    }

    /**
     * Get the system CPU load.
     * @return The system CPU load.
     */
    public double getSystemCpuLoad() {
        return systemCpuLoad;
    }
    
    /**
     * Get the Agent's uptime in milliseconds.
     * This is the amount of time since the Agent was created.
     * @return The subsystem uptime in milliseconds.
     */
    public int getUptime() {
        return uptime;
    }

}
